@@ -2413,7 +2413,7 @@ xfce_appfinder_model_execute (XfceAppfinderModel  *model,
                             argv, NULL, G_SPAWN_SEARCH_PATH,
                             garcon_menu_item_supports_startup_notification (item),
                             gtk_get_current_event_time (),
-                            icon, FALSE, error);
+                            icon, TRUE, error);
 #else
       succeed = xfce_spawn_on_screen (screen,
                                       garcon_menu_item_get_path (item),
