@@ -53,15 +53,14 @@ void    appfinder_refcount_debug_add (GObject     *object,
 #endif
 
 #define XFCE_APPFINDER_STOCK_BOOKMARK_NEW "bookmark-new"
-#define XFCE_APPFINDER_STOCK_CLEAR "edit-clear"
-#define XFCE_APPFINDER_STOCK_CLOSE "window-close"
+#define XFCE_APPFINDER_STOCK_CLEAR "edit-clear-symbolic"
 #define XFCE_APPFINDER_STOCK_DELETE "edit-delete"
 #define XFCE_APPFINDER_STOCK_DIALOG_ERROR "dialog-error"
 #define XFCE_APPFINDER_STOCK_EDIT "document-properties"
 #define XFCE_APPFINDER_STOCK_EXECUTE "system-run"
 #define XFCE_APPFINDER_STOCK_FIND "edit-find"
-#define XFCE_APPFINDER_STOCK_GO_DOWN "go-down"
-#define XFCE_APPFINDER_STOCK_GO_UP "go-up"
+#define XFCE_APPFINDER_STOCK_GO_DOWN "go-down-symbolic"
+#define XFCE_APPFINDER_STOCK_GO_UP "go-up-symbolic"
 #define XFCE_APPFINDER_STOCK_PREFERENCES "preferences-system"
 #define XFCE_APPFINDER_STOCK_REVERT_TO_SAVED "document-revert"
 #define XFCE_APPFINDER_STOCK_REMOVE "list-remove"
