@@ -145,7 +145,8 @@ appfinder_window_destroyed (GtkWidget *window)
   if (model_cache == NULL)
     {
       APPFINDER_DEBUG ("main took reference on the main model");
-      model_cache = xfce_appfinder_model_get ();
+      channel = xfconf_channel_get ("xfce4-appfinder");
+      model_cache = xfce_appfinder_model_get (xfconf_channel_get_bool (channel, "/sort-by-frecency", FALSE));
     }
 
   /* remove from internal list */
@@ -221,11 +222,6 @@ main (gint argc, gchar **argv)
   g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
 #endif
 
-#if !GLIB_CHECK_VERSION (2, 32, 0)
-  if (!g_thread_supported ())
-    g_thread_init (NULL);
-#endif
-
   /* get the startup notification id */
   startup_id = g_getenv ("DESKTOP_STARTUP_ID");
 
